@@ -1,12 +1,17 @@
-from typing import Any, Type, Optional, Callable
+from typing import Any, Type, Optional, Callable, List
 from pydantic import BaseModel
 
 
 class FunctionArgInfo(BaseModel):
     name: str
-    type: Optional[Type] = None
+    types: Optional[List[Type]] = None
     default_value: Optional[Any] = None
 
+    def check_type(self, type: Type) -> bool:
+        if self.types is None:
+            return False
+        return any([issubclass(t, type) for t in self.types])
+
 
 class FunctionInformation(BaseModel):
     function_object: Callable
